@@ -1,4 +1,4 @@
-/*	$Id: Class1.h,v 1.18 2008/11/24 06:17:59 faxguy Exp $ */
+/*	$Id: Class1.h 1106 2012-06-18 23:50:58Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -66,6 +66,8 @@ protected:
     bool	jbigSupported;		// whether or not JBIG is supported in this mode
     bool	senderHasV17Trouble;	// whether or not a sender has trouble with V.17
     bool	senderSkipsV29;		// whether or not a sender skips over V.29 usage
+    int		dataSent;		// how much data the sender transmitted
+    int		dataMissed;		// how much data from the sender was missed
     const u_char* frameRev;		// HDLC frame bit reversal table
     fxStr	lid;			// encoded local id string
     fxStr	pwd;			// transmit password
@@ -218,9 +220,10 @@ public:
     CallStatus	dialResponse(fxStr& emsg);
     FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&, u_int&);
     void	sendBegin();
+    void	getDataStats(FaxSetup* setupinfo);
     void	sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     FaxSendStatus sendPhaseB(TIFF* tif, Class2Params&, FaxMachineInfo&,
-		    fxStr& pph, fxStr& emsg, u_int& batched);
+		    fxStr& pph, fxStr& emsg, u_int& batched, u_short& npages);
     void	sendEnd();
     void	sendAbort();
 
