@@ -1,4 +1,4 @@
-/*	$Id: Class2.h,v 1.13 2007/11/04 01:45:30 faxguy Exp $ */
+/*	$Id: Class2.h 1106 2012-06-18 23:50:58Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -143,8 +143,9 @@ public:
     CallStatus	dialResponse(fxStr& emsg);
     FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&, u_int&);
     FaxSendStatus sendPhaseB(TIFF* tif, Class2Params&, FaxMachineInfo&,
-		    fxStr& pph, fxStr& emsg, u_int& batched);
+		    fxStr& pph, fxStr& emsg, u_int& batched, u_short& npages);
     void	sendAbort();
+    void	getDataStats(FaxSetup* setupinfo);
 
 // receive support
     bool	setupReceive();
