@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h,v 1.15 2008/07/16 16:17:39 faxguy Exp $ */
+/*	$Id: ClassModem.h 1114 2012-07-02 18:27:37Z faxguy $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -98,7 +98,8 @@ public:
 	FAILURE	   = 6,		// other problem (e.g. modem turned off)
 	NOFCON	   = 7,		// carrier established, but phase a failure
 	DATACONN   = 8,		// data carrier established
-	RING	   = 9		// glare - ring detected after dial
+	RING	   = 9,		// glare - ring detected after dial
+	V34FAIL	   = 10		// V.34 handshake failure
     };
 
     enum {			// ClassModem::CallType
@@ -204,7 +205,7 @@ protected:
     fxStr	revQueryCmd;	// product revision identification command
 
     static const char* serviceNames[9];	 // class 2 services
-    static const char* callStatus[10];	 // printable call status
+    static const char* callStatus[11];	 // printable call status
     static const char* ATresponses[19];
 
     ClassModem(ModemServer&, const ModemConfig&);
@@ -253,6 +254,7 @@ public:
     const fxStr& getCallIDType(int i) const;
 // data transfer timeout controls
     void	setDataTimeout(long secs, u_int br);
+    void	setDataTimeout(long datasize, int discount, u_int br);
     long	getDataTimeout() const;
 // miscellaneous
     void	pause(u_int ms);
@@ -266,6 +268,7 @@ public:
     void	beginTimedTransfer();
     void	endTimedTransfer();
     bool	wasTimeout();
+    bool	wasModemError();
     void	setTimeout(bool);
     void	flushModemInput();
     bool	putModem(void* data, int n, long ms = 0);
