@@ -1,4 +1,4 @@
-/*	$Id: FaxModem.h,v 1.16 2008/11/24 06:17:59 faxguy Exp $ */
+/*	$Id: FaxModem.h 1108 2012-06-26 03:56:56Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -49,6 +49,8 @@ typedef unsigned int JBIGSupport;	// JBIG support available
 typedef struct {
     bool	senderSkipsV29;		// if sender skips V.29 usage
     bool	senderHasV17Trouble;	// if we have trouble understanding sender's V.17
+    int		senderDataSent;		// how much data the sender transmitted
+    int		senderDataMissed;	// how much data which the sender transmitted was missing or corrupt
 } FaxSetup;
 
 /*
@@ -74,7 +76,7 @@ private:
     fxStr	tagLineLocale;	// locale setting for tagline
     u_int	tagLineFields;	// number of fields in the tag line
 
-    void	setupTagLine(const FaxRequest&, const fxStr& tagLineFmt, const fxStr& locale);
+    void	setupTagLine(const FaxRequest&, const fxStr& tagLineFmt, const fxStr& locale, const fxStr& tz);
 // phase c data receive & copy quality checking
     u_int	cblc;		// current count of consecutive bad lines
     bool	lastRowBad;	// last decoded row was bad
@@ -86,14 +88,14 @@ private:
     tstrip_t	recvStrip;	// current strip number during receive
     u_char*	recvRow;	// current receive row raster
     u_char*	recvPageStart;	// pointer to start of page buffer
-    u_long*	savedWriteOff;	// file offset at start of page data
-    u_long*	savedStripByteCounts;	// byte counts at start of page data
+    tiff_offset_t*	savedWriteOff;	// file offset at start of page data
+    TIFFSTRIPBYTECOUNTS*	savedStripByteCounts;	// byte counts at start of page data
     int		decodedPixels;	// number of pixels decoded with error
     int		decoderFd[2];	// file descriptors for the decoder pipe
     int		counterFd[2];	// file descriptors for the counter pipe
     pid_t	decoderPid;	// process id for the decoding process
     u_char	parserBuf[16];	// buffer used for parsing JBIG and JPEG
-    u_long	parserCount[3];	// counters used in parsing JBIG and JPEG
+    u_long	parserCount[4];	// counters used in parsing JBIG and JPEG
     int		imagefd;	// file descriptor for image file
 
     void	flushEncodedData(TIFF*, tstrip_t, const u_char*, u_int, fxStr& emsg);
@@ -219,6 +221,7 @@ public:
     virtual bool supportsPageLength(u_int l) const;
     virtual bool supportsPolling() const;
     virtual bool supportsECM(u_int ec = 0) const;
+    virtual bool supportsJPEG(u_int jp = 0) const;
 
     virtual int selectSignallingRate(int br) const;
     u_int getBestSignallingRate() const;
@@ -263,7 +266,7 @@ public:
 	bool& hasDoc, fxStr& emsg, u_int& batched) = 0;
     virtual void sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     virtual FaxSendStatus sendPhaseB(TIFF*, Class2Params&, FaxMachineInfo&,
-	fxStr& pph, fxStr& emsg, u_int& batched) = 0;
+	fxStr& pph, fxStr& emsg, u_int& batched, u_short& npages) = 0;
     virtual void sendEnd();
     virtual void sendAbort() = 0;
     // query interfaces for optional state
@@ -300,6 +303,7 @@ public:
      */
     virtual bool setupReceive() = 0;
     virtual bool recvBegin(FaxSetup* setupinfo, fxStr& emsg);
+    virtual void getDataStats(FaxSetup* setupinfo);
     virtual bool recvEOMBegin(FaxSetup* setupinfo, fxStr& emsg);
     virtual bool recvPage(TIFF*, u_int& ppm, fxStr& em, const fxStr& id) = 0;
     virtual bool recvEnd(FaxSetup* setupinfo, fxStr& emsg) = 0;
