@@ -1,4 +1,4 @@
-/*	$Id: FaxRequest.h,v 1.12 2008/09/14 10:33:12 faxguy Exp $ */
+/*	$Id: FaxRequest.h 1108 2012-06-26 03:56:56Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -118,6 +118,9 @@ public:
     int		skippedpages;	// start page numbering here + 1
     u_short	serverdocover;	// server should create the coverpage
     u_short	nocountcover;	// don't count these pages
+    u_short	probeonly;	// this job is only to probe the receiver
+    u_short	conntime;	// connection time on last session
+    u_short	duration;	// duration time on last session
     u_short	ntries;		// # tries to send current page
     u_short	ndials;		// # consecutive failed tries to call dest
     u_short	totdials;	// total # calls to dest
@@ -137,6 +140,7 @@ public:
     u_short	desiredtl;	// desired tagline handling
     u_short	useccover;	// whether to use continuation cover page
     u_short	usexvres;	// whether to use extended VR
+    u_short	usecolor;	// whether to use color
     u_short	pagechop;	// whether to do page chopping
     u_short	notify;		// email notification flags
     u_short	ignoremodembusy;// ignore modem busy status
@@ -178,6 +182,7 @@ public:
     fxStr	csi;		// CSI string from receiving equipment (ASCII representation)
     fxStr	nsf;		// NSF string from receiving equipment (ASCII representation)
     fxStr	timeofday;	// time of day restrictions
+    fxStr	timezone;	// timezone to use in tag line
     fxStr	errorcode;	// error code for status
     pid_t	writeQFilePid;	// pid of last writeQFile operation
     FaxItemArray items;	// set of requests
