@@ -1,4 +1,4 @@
-/*	$Id: HylaFAXServer.h,v 1.23 2008/10/12 04:15:56 faxguy Exp $ */
+/*	$Id: HylaFAXServer.h 1108 2012-06-26 03:56:56Z faxguy $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -32,11 +32,14 @@
 #include "StrArray.h"
 #include "FaxRequest.h"
 #include "FaxRecvInfo.h"
+/* SendFaxClient.h must come before manifest.h due to conflicts */
+#include "SendFaxClient.h"
 #include "manifest.h"
 #include "FileCache.h"
 #include "Trace.h"
 #include "Trigger.h"
 #include "SystemLog.h"
+#include "FaxHostID.h"
 
 #include "config.h"
 
@@ -62,6 +65,12 @@ extern "C" {
 #include <setjmp.h>
 #include <errno.h>
 
+class MySendFaxClient : public SendFaxClient {
+public:
+    MySendFaxClient();
+    ~MySendFaxClient();
+};
+
 /*
  * In-memory copy of a job description file.
  */
@@ -126,7 +135,7 @@ enum Token {
     T_ABOR,	 T_ACCT,	T_ADDMODEM,	T_ADDUSER,	T_ADMIN,
     T_ALLO,	 T_ANSWER,	T_APPE,		T_CHMOD,	T_CHOWN,
     T_CONFIG,	 T_CWD, 	T_CDUP,		T_DELE,		T_DELUSER,
-    T_DELMODEM,	 T_DISABLE,	T_ENABLE,	T_FILEFMT,	T_FORM,
+    T_DELMODEM,	 T_DISABLE,	T_ENABLE,	T_EPSV,		T_EPRT,		T_FILEFMT,	T_FORM,
     T_HELP,	 T_IDLE,	T_LOCKWAIT,	T_JDELE,	T_JGDELE,	T_JGINTR,
     T_JGKILL,	 T_JGNEW,	T_JGPARM,	T_JGREST,	T_JGRP,
     T_JGSUB,	 T_JGSUSP,	T_JGWAIT,	T_JINTR,	T_JKILL,
@@ -145,14 +154,14 @@ enum Token {
     T_COMMENTS,	 T_COMMID,	T_COVER,	T_DATAFORMAT,	T_DIALSTRING,
     T_DOCUMENT,	 T_DONEOP,	T_EXTERNAL,	T_FAXNUMBER,	T_FAXNAME,	T_FROM_COMPANY,	T_FROM_LOCATION,
     T_FROM_USER, T_FROM_VOICE,	T_GROUPID,	T_HRES,		T_IGNOREMODEMBUSY, T_JOBID,
-    T_JOBINFO,	 T_JOBTYPE,	T_LASTTIME,	T_MAXDIALS,	T_MAXPAGES,
+    T_JOBINFO,	 T_JOBTYPE,	T_LASTTIME,	T_MAXDIALS,
     T_MAXTRIES,	 T_MINBR,	T_MODEM,	T_NDIALS,	T_NOTIFY,
     T_NOTIFYADDR,T_NPAGES,	T_NTRIES,	T_OWNER,	T_PAGECHOP,
     T_PAGELENGTH,T_PAGEWIDTH,	T_PASSWD,	T_POLL,		T_REGARDING,
     T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_SKIPPAGES,	T_SKIPPEDPAGES,	T_STATE,	T_STATUS,	T_ERRORCODE,
-    T_SUBADDR,	 T_TAGLINE,	T_TIMEOFDAY,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,
+    T_SUBADDR,	 T_TAGLINE,	T_TIMEOFDAY,	T_TIMEZONE,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,	T_PROBEONLY,
     T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_TSI,		T_USE_CONTCOVER, T_NOCOUNTCOVER, T_SERVERDOCOVER,
-    T_USE_ECM,	 T_ECMTYPE,	T_USE_TAGLINE,	T_USE_XVRES,	T_USRKEY,	T_VRES,
+    T_USE_ECM,	 T_ECMTYPE,	T_USE_TAGLINE,	T_USE_XVRES,	T_USE_COLOR,	T_USRKEY,	T_VRES, T_CONNTIME, T_DURATION,
     /*
      * SNPP tokens.
      */
@@ -199,6 +208,7 @@ public:
         u_int		 def;
     };
     static int _debugSleep;
+    static fxStrArray	configOptions;		// Pased on the command line
 protected:
     u_int	state;
 #define	S_LOGGEDIN	0x0001		// client is logged in
@@ -223,6 +233,7 @@ protected:
     fxStr	clientFIFOName;		// client FIFO name
     int		faxqFd;			// faxq FIFO open descriptor
     int		clientFd;		// client FIFO open descriptor
+    int		ignore_fd;		// ignore FIFO write descriptor to avoid EOF
     fxStr	fifoResponse;		// response received to FIFO msg
     u_int	idleTimeout;		// client inactivity timeout
     u_int	maxIdleTimeout;		// upper bound on idle timeout
@@ -230,6 +241,10 @@ protected:
     u_int	maxLockTimeout;		// upper bound on qfile lock timeout
     int		data;			// current data connection (socket)
     int		pdata;			// passive mode data connect (socket)
+    fxStr	jobHostId;		// id of this host for jobid/groupid
+    FaxHostIDArray jobHosts;		// array for other known job hosts
+    MySendFaxClient* jobHostClient;	// client connection for job host
+    int		curJobHost;		// currently-connected job host
     fxStr	hostname;		// name of machine server is running on
     fxStr	hostaddr;		// primary address for hostname
     fxStr	remotehost;		// name of peer's machine
@@ -250,8 +265,10 @@ protected:
 	bool	pam_chrooted;	// if already chrooted, PAM gets disabled
 #endif
 
-    fxStr	passWd;			// encrypted user password
-    fxStr	adminWd;		// encrypted passwd for admin privileges
+    fxStr	passWd;			// encrypted user password - read from hosts.hfaxd
+    fxStr	adminWd;		// encrypted passwd for admin privileges - read from hosts.hfaxd
+    fxStr	usrPassWd;		// unencrypted user password - read from user
+    fxStr	usrAdminWd;		// unencrypted passwd for admin privileges - read from user
 #ifdef HAVE_LDAP
     fxStr	ldapServerUri;		// URL for the LDAP Server
     fxStr	ldapBaseDN;		// LDAP base DN where user objects are found
@@ -303,6 +320,8 @@ protected:
     Job		defJob;			// default job state information
     JobDict	jobs;			// non-default jobs
     Job*	curJob;			// current job
+    fxStr	curJobId;		// current job id
+    fxStr	curJobGroupId;		// current job group id
     fxStr	jobFormat;		// job status format string
     JobDict	blankJobs;		// jobs created during this session but not submitted
     /*
@@ -351,7 +370,7 @@ protected:
     void chmodCmd(const char*, u_int);	// CHMOD
 
     virtual void passiveCmd(void) = 0;	// PASV: depends on transport
-    virtual void portCmd(void) = 0;	// PORT: depends on transport
+    virtual void portCmd(Token) = 0;	// PORT: depends on transport
 
     void triggerCmd(const char*, ...);	// TRIGGER
 
@@ -573,10 +592,11 @@ protected:
     void newJobCmd(void);
     bool newJob(fxStr& emsg);
     Job* findJob(const char* jobid, fxStr& emsg);
-    Job* findJobInMemmory(const char* jobid);
+    Job* findJobInMemory(const char* jobid);
     Job* findJobOnDisk(const char* jobid, fxStr& emsg);
     bool updateJobFromDisk(Job& job);
     void replyCurrentJob(const char* leader);
+    bool setupJobHost(const char* jobid, fxStr& emsg);
     void setCurrentJob(const char* jobid);
     Job* preJobCmd(const char* op, const char* jobid, fxStr& emsg);
     void operateOnJob(const char* jobid, const char* what, const char* op);
