@@ -1,4 +1,4 @@
-/*	$Id: FaxClient.h,v 1.9 2008/03/12 05:43:09 faxguy Exp $ */
+/*	$Id: FaxClient.h 1066 2011-11-28 20:00:34Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -241,8 +241,10 @@ public:
     bool jobParm(const char* name, bool b);
     bool jobParm(const char* name, u_int v);
     bool jobParm(const char* name, float v);
+    bool jobParm(const char* name);
     bool jobSendTime(const struct tm tm);
     bool jobLastTime(u_long);
+    bool jobLastTime(const char*);
     bool jobRetryTime(u_long);
     bool jobCover(const char* docname);
     bool jobDocument(const char* docname);
@@ -280,8 +282,8 @@ public:
     /*
      * Retrieve information from the server.
      */
-    bool recvData(bool (*f)(int, const char*, int, fxStr&),
-    int arg, fxStr& emsg, u_long restart, const char* fmt, ...);
+    bool recvData(bool (*f)(void*, const char*, int, fxStr&),
+    void* arg, fxStr& emsg, u_long restart, const char* fmt, ...);
     bool recvZData(bool (*f)(void*, const char*, int, fxStr&),
     void* arg, fxStr& emsg, u_long restart, const char* fmt, ...);
     /*
